@@ -1,5 +1,7 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+from . import rowingdata
 from sys import argv
 
 def main():
@@ -8,6 +10,6 @@ def main():
     except IndexError:
 	boatFile="my1x.txt"
 
-    print(rowingdata.boatedit(boatFile))
+    print((rowingdata.boatedit(boatFile)))
 
     print("done")
